==> democracys-library-0.0.1-a13.tgz: package/src/data/carousel-1.ts <==
export type CarouselCard = {
  id: string;
  title: string;
  image: string;
};

export const carousel1Title = 'INTERESTING GOVERNMENT DOCS';

export const carousel1: CarouselCard[] = [
  {
    id: 'MH07D7178',
    title: 'Fundraising for Social Change, Part One',
    image: 'https://archive.org/services/img/MH07D7178',
  },
  {
    id: 'CAT92272736',
    title: 'Two keys for appraising forest fire fuels',
    image: 'https://archive.org/services/img/CAT92272736',
  },
  {
    id: 'CAT79708698031',
    title: 'Hamburger—Questions and Answers',
    image: 'https://archive.org/services/img/CAT79708698031',
  },
  {
    id: 'usda-posters',
    title: 'U.S. Department of Agriculture Poster Collection',
    image: 'https://archive.org/services/img/CAT31123678',
  },
  {
    id: 'selectedpolishso00army',
    title: 'Selected Polish songs',
    image: 'https://archive.org/services/img/selectedpolishso00army',
  },
  {
    id: 'blueprintforfutu9611unit',
    title: 'Blueprint for the future',
    image: 'https://archive.org/services/img/blueprintforfutu9611unit',
  },
  {
    id: 'introductionlapt00albe',
    title: 'Introduction à la pâtisserie',
    image: 'https://archive.org/services/img/introductionlapt00albe',
  },
  {
    id: 'hintsonmountainl94youn',
    title: 'Hints on mountain-lion trapping',
    image: 'https://archive.org/services/img/hintsonmountainl94youn',
  },
  {
    id: 'drylandfarmingin00cott',
    title: 'Dry land farming in the Southwest',
    image: 'https://archive.org/services/img/drylandfarmingin00cott',
  },
];

==> democracys-library-1.0.1.tgz: package/src/data/carousel-1.ts <==
export type CarouselCard = {
  id: string;
  title: string;
  image: string;
};

export const carousel1Title = 'COLLECTION HIGHLIGHTS';

export const carousel1: CarouselCard[] = [
  {
    id: 'MH07D7178',
    title: 'Fundraising for Social Change, Part One',
    image: 'https://archive.org/services/img/MH07D7178',
  },
  {
    id: 'CAT92272736',
    title: 'Two keys for appraising forest fire fuels',
    image: 'https://archive.org/services/img/CAT92272736',
  },
  {
    id: 'CAT79708698031',
    title: 'Hamburger—Questions and Answers',
    image: 'https://archive.org/services/img/CAT79708698031',
  },
  {
    id: 'usda-posters',
    title: 'U.S. Department of Agriculture Poster Collection',
    image: 'https://archive.org/services/img/CAT31123678',
  },
  {
    id: 'selectedpolishso00army',
    title: 'Selected Polish songs',
    image: 'https://archive.org/services/img/selectedpolishso00army',
  },
  {
    id: 'blueprintforfutu9611unit',
    title: 'Blueprint for the future',
    image: 'https://archive.org/services/img/blueprintforfutu9611unit',
  },
  {
    id: 'introductionlapt00albe',
    title: 'Introduction à la pâtisserie',
    image: 'https://archive.org/services/img/introductionlapt00albe',
  },
  {
    id: 'hintsonmountainl94youn',
    title: 'Hints on mountain-lion trapping',
    image: 'https://archive.org/services/img/hintsonmountainl94youn',
  },
  {
    id: 'drylandfarmingin00cott',
    title: 'Dry land farming in the Southwest',
    image: 'https://archive.org/services/img/drylandfarmingin00cott',
  },
];
